#
# spec file for package libgee
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2010 Luis Medinas, Portugal
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libgee
VCS: https://src.suse.de/SLFO-pool/libgee#cbbcd7146be0729db1c138beb1b78b3673448ef9fbd2a1a0c926036b9dd07d22
Version:        0.20.8
Release:        160000.3.1
Summary:        GObject-based library providing commonly used data structures
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://wiki.gnome.org/Projects/Libgee
Source0:        https://download.gnome.org/sources/libgee/0.20/%{name}-%{version}.tar.xz

BuildRequires:  gobject-introspection-devel
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.25.1
BuildRequires:  pkgconfig(glib-2.0) >= 2.36

%description
Libgee is a collection library providing GObject-based interfaces and
classes for commonly used data structures.

%package -n libgee-0_8-2
Summary:        GObject-based library providing commonly used data structures
Group:          System/Libraries

%description -n libgee-0_8-2
Libgee is a collection library providing GObject-based interfaces and
classes for commonly used data structures.

This package provides Libgee's shared libraries.

%package -n typelib-1_0-Gee-0_8
Summary:        Introspection bindings for Libgee
Group:          System/Libraries

%description -n typelib-1_0-Gee-0_8
Libgee is a collection library providing GObject-based interfaces and
classes for commonly used data structures.

This package provides the GObject Introspection bindings for Libgee.

%package -n libgee-devel
Summary:        Development files for Libgee
Group:          Development/Libraries/GNOME
Requires:       libgee-0_8-2 = %{version}
Requires:       typelib-1_0-Gee-0_8 = %{version}

%description -n libgee-devel
Libgee is a collection library providing GObject-based interfaces and
classes for commonly used data structures.

This package provides all the files needed for development using Libgee.

%prep
%autosetup -p1
find -name '*.vala' -exec touch {} \;

%build
%configure \
	--disable-static \
	--enable-vala \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n libgee-0_8-2

%check
make check

%files -n libgee-0_8-2
%license COPYING
%doc NEWS README
%{_libdir}/*.so.*

%files -n typelib-1_0-Gee-0_8
%{_libdir}/girepository-1.0/Gee-0.8.typelib

%files -n libgee-devel
%doc AUTHORS ChangeLog MAINTAINERS
%{_includedir}/gee-0.8/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/*.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/*.vapi

%changelog
* Thu Jan 16 2025 bjorn.lie@gmail.com
- Update to version 0.20.8:
  + Fixes for newer valac.
- Drop patches fixed upstream:
  + ce8461ff6ea8ed79ce06b4241cb4fbb6d3d314f1.patch
  + b33a6627f4fc96938b6015e05849867c472160a8.patch
  + 2f0bbe8987e5eb1390b23ac531c971b202c2ef77.patch
- Add check section and run make check during build.
* Sat Jul  6 2024 bjorn.lie@gmail.com
- Trigger Vala compilation during build, for GCC 14 compatibility.
- Add ce8461ff6ea8ed79ce06b4241cb4fbb6d3d314f1.patch: Drop
  unsupported inline modifier on constructor and destructor
  declarations.
* Tue Mar  5 2024 dimstar@opensuse.org
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Fri Oct 13 2023 bjorn.lie@gmail.com
- Add upstream patches:
  + b33a6627f4fc96938b6015e05849867c472160a8.patch: Add more
    missing generic type arguments.
  + 2f0bbe8987e5eb1390b23ac531c971b202c2ef77.patch: Implementations
    of "G List.get()" should use non-nullable return as defined.
* Sat Sep 17 2022 bjorn.lie@gmail.com
- Update to version 0.20.6:
  + Fixes for newer valac.
  + Keep the original exception in Future.map/flat_map.
* Thu Feb 10 2022 bjorn.lie@gmail.com
- Update to version 0.20.5:
  + Fixes for newer valac.
  + Use Makefile.introspection instead of custom rule.
- Drop conditional Requires for long obsolete versions of openSUSE.
- Modernize spec, use ldconfig_scriptlets macro for post(un)
  handling and other current macros.
* Thu Mar 18 2021 dimstar@opensuse.org
- Update to version 0.20.4:
  + Fixes for newer valac.
* Sun Feb  9 2020 bjorn.lie@gmail.com
- Update to version 0.20.3:
  + Minor warning fixes for newer valac.
  + Guard GLib.Cond.wait/wait_until calls against spurious or
    stolen wakeups.
* Mon Aug  5 2019 bjorn.lie@gmail.com
- Update to version 0.20.2:
  + Minor build fixes.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Feb 11 2018 luc14n0@linuxmail.org
- Update to version 0.20.1:
  + Minor bug fixes.
- Update Url tag to https://wiki.gnome.org/Projects/Libgee: the
  current Libgee's web page.
- Remove idempotent %%clean section: RPM already does this work.
- Update package summaries and descriptions making them either
  shorter or more content-descriptive.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 0.20.0:
  + No changes.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 0.19.91:
  + Fix to_array on enums and flags.
  + Add additional query operations to Traversable.
* Wed Oct 12 2016 zaitor@opensuse.org
- Update to version 0.18.1:
  + Various build and runtime fixes.
- Stop passing V=1 to make, we do debugging locally.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Thu Oct  8 2015 dimstar@opensuse.org
- Add baselibs.conf: provide libgee-0_8-2 as required by
  libskk0-32bit (boo#949452).
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to vesion 0.18.0:
  + Stable release, no changes since 0.17.92.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 0.17.92:
  + Fix default value of --enable-consistency-check.
* Tue Oct 14 2014 dimstar@opensuse.org
- Update to version 0.16.1:
  + Workaround GC thread consuming 100%% of CPU.
  + Fix HashMap destructor name.
  + Fix a documentation typo.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 0.16.0:
  + No changes since previous release.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 0.15.92:
  + Improve documentation.
* Wed Aug 20 2014 dimstar@opensuse.org
- Update to version 0.15.90:
  + Add explicit tee implementations.
  + Improve the benchmark.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 0.15.3:
  + Add UnrolledLinkedList class implementing List and Deque
    interface.
  + Clarify the add and insert operation on list iterators and make
    the behaviour consistent for ArrayList and LinkedList.
  + Allow (partially) disable internal asserts.
  + Internal symbols are hidden.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 0.14.0:
  + No changes since version 0.13.91.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 0.13.91:
  + Fix HazardPointer bugs.
  + Fix List test.
* Mon Mar 10 2014 zaitor@opensuse.org
- Update to version 0.13.90:
  + Fix the broken test.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 0.13.5.1:
  + Remove workaround for 'old' (<0.23.2) vala.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 0.13.5:
  + Use WeakRef for keeping of read-only proxy for collection.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 0.13.4:
  + The collection cloning no longer leaks memory.
  + Various warning fixes.
* Sun Mar  9 2014 zaitor@opensuse.org
- Update to version 0.12.1:
  + Fix the HazardPointer bugs.
- Stop using export CFLAGS="%%{optflags} -w" even if bgo#682526 is
  not marked as fixed as it's not needed anymore.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 0.12.0:
  + No changes since previous release.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 0.11.92:
  + Override read_only_view property in ReadOnlySortedMap and its
    subclasses.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 0.11.91:
  + Bump the GLib requirements to 2.36 in configure.ac.
* Tue Aug 27 2013 dimstar@opensuse.org
- Update to version 0.11.90:
  + Add adding to collection based on iterators.
  + Make Collection.add_all_array, contains_all_array and
    remove_all_array virtual.
  + Avoid destroy coroutine creation in hazard pointer
    implementation.
  + Various bugfixes.
- Changes from version 0.11.5:
  + Add Traversable.tee.
  + Add exception handling to Future.
  + Add ability of getting Future from Lazy.
  + Make Traversable.flat_map a virtual function.
  + Add more specializations to .foreach.
  + Improve the test.
  + Various bugfixes.
- Changes from version 0.11.4:
  + Add flat_map method to Traversable.
  + Add zip method to Future.
  + Specialize stream iterator (4-22%% speed improvement in tests).
  + Extend the Traversable.Stream with Stream.WAIT.
  + Fix lazy value usage in unfold.
- Changes from version 0.11.0:
  + Add futures and promises to libgee.
  + Update the build system.
  + Return true from HashSet.Iterator.foreach() if we fall off the
    end.
* Wed Aug 21 2013 zaitor@opensuse.org
- Update to version 0.10.4:
  + Fix various problems with generic arrays.
* Tue Aug  6 2013 zaitor@opensuse.org
- Update to version 0.10.3:
  + Fix various .foreach.
* Sat Jul 27 2013 zaitor@opensuse.org
- Update to version 0.10.2:
  + Use .value instead of value directly in unfold.
* Thu Apr 11 2013 dimstar@opensuse.org
- Update to version 0.10.1:
  + Fix HashSet.foreach.
* Fri Mar 29 2013 vuntz@opensuse.org
- Update to version 0.10.0:
  + No change since 0.9.92.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 0.9.92:
  + Fix memory leak in TreeSet and TreeMap.
* Sun Feb 17 2013 dimstar@opensuse.org
- Update to version 0.9.91:
  + ConcurrentSet implements SortedSet.
  + Fix HashMultiMap, TreeMultiSet constructor.
  + Add add/contains/remove_all working on array.
  + Allow creation of ArrayList from array.
  + Add read_only_view to Gee.MultiSet and Gee.MultiMap.
* Thu Jan 10 2013 dimstar@opensuse.org
- Update to version 0.9.0:
  + ConcurrentSet preliminary implementation.
  + Bugfixes from 0.8.2 and 0.8.3.
  + Fix various Vala warnings.
  + First part of test refactoring.
- Changes from version 0.8.1:
  + Allow slice in ReadOnlyList.
  + Fix Iterator.remove in PriorityQueue.
  + Add foreach specializations.
  + Use foreach function instead of iterators.
- Drop libgee-gir.patch: fixed upstream.
* Sun Oct 21 2012 dimstar@opensuse.org
- Update to version 0.8.0:
  + Fix Traversable.chop (bgo#684348).
  + Remove unnecessary method.
  + Update README.
  + Move everything to GenericAccessor.
- Changes from version 0.7.90:
  + Don't notify when constructor property is set.
  + Use views instead of copies in MultiMap as in rest of libgee
  + Allow early termination in Traversable.foreach.
- Changes from version 0.7.4.1:
  + Fix missing property read_only in testmap Entry.
- Changes from version 0.7.4:
  + Remove *_impl methods
  + Move virtual methods to interfaces
  + Future-proof the ABI by adding reserved v-table members
  + Add read_only to Map.Entry
- Changes from version 0.7.3:
  + Update documentation
  + Fix iteration order in hashtables
  + Split SortedMap/SortedSet into bi-directional and
    uni-directional parts
  + Simplify CompareDataFunc/HashDataFunc/EqualDataFunc
  + Fix HazardPointers
- Changes from version 0.7.2:
  + Require *_type property for all collections
  + Add ArrayQueue
  + Few bug fixes
- Changes frmo version 0.7.1:
  + Implement hazard pointers and concurrent linked lists
  + Respect VALAFLAGS when building tests
  + Fix a few compiling warnings
- Changes from version 0.7.0:
  + Build system using the automake 1.11 vala support
  + Move to delegates with targets and move them to Gee namespace
  + Gee.Hashable interface
  + Improve Iterator allowing to, among others, query about state
    of iterator
  + Allow checking if Iterator or Collection is read-only
  + Introducing highier-level function via Traversable interface
  + Introduce support for lazy values
  + Allow to install in parallel with 0.6
- Rename typelib-1_0-Gee-1_0 subpackage to typelib-1_0-Gee-0_8,
  following upstreams rename.
- Rename libgee2 subpackage to libgee-0_8-2, following upstreams
  rename.
- Injext -w into CFLAGS as a workaround for bgo#682526.
* Sat Oct 20 2012 zaitor@opensuse.org
- Update to version 0.6.6:
  + Fix iterator.remove in PriorityQueue.
* Wed Aug 15 2012 dimstar@opensuse.org
- Update to version 0.6.5:
  + Prevent hashtables from resizing during iteration.
* Fri Feb 24 2012 vuntz@opensuse.org
- Update to version 0.6.4:
  + Fix compilation with vala master
  + Fix creation of GObject introspection files
- Changes from version 0.6.3:
  + Fix buffer underflow.
- Changes from version 0.6.2.1:
  + Add check-news to AM_INIT_AUTOMAKE
- Changes from version 0.6.2:
  + Fix adding second element to priority queue.
  + Fix problem with key used in range is freed.
- Rebase libgee-gir.patch.
* Tue Jan 10 2012 vuntz@opensuse.org
- Add a typelib-1_0-Gee-1_0 Requires to libgee2 subpackage on 12.1
  and earlier: this shouldn't be needed, but unfortunately, this is
  needed for people using GNOME:Apps with 12.1. Otherwise,
  typelib-1_0-Gee-1_0 doesn't get installed and gnome-shell will
  stop working.
* Tue Dec 13 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Gee-1_0 subpackage.
- Add typelib-1_0-Gee-1_0 Requires to libgee-devel subpackage.
- Add libgee-gir.patch: Make sure the typelib file references the
  real library name.
- Drop glib2-devel Requires from -devel package: it is
  automatically added the pkgconfig()-way.
* Mon Mar 21 2011 dimstar@opensuse.org
- Update to version 0.6.1:
  +  Fix memory leaks in LinkedList.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 0.6.0:
  + Fix compiler warning.
* Thu Sep 16 2010 vuntz@opensuse.org
- Update to version 0.5.3:
  + Fix memory leaks in TimSort and LinkedList.
  + Bug fixes in TreeMap and TreeSet.
* Wed Aug  4 2010 dimstar@opensuse.org
- Update to version 0.5.2:
  + Build system enhancements to conform Gnome's style.
  + Bug fixes in TreeSet, TreeMap and Collection.to_array.
  + Deprecated Map methods marked with [Deprecated].
- Move *.gir to -devel package and package also the typelib.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.5.1:
  + Bug fixes in HashMultiSet, TimSort, TreeMap, TreeMultiSet, and
    TreeSet.
  + Fix build with Vala 0.8.0 and later
  + Fix build on Windows
  + Fix subprocess handling in test infrastructure
* Wed Jan  6 2010 lmedinas@opensuse.org
- Initial package for openSUSE.
